==> open-xchange-publish-infostore-online_6.14.0.0.orig.tar.gz: open-xchange-publish-infostore-online-6.14.0.0/src/com/openexchange/publish/online/infostore/InfostoreDocumentPublicationService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.publish.online.infostore;

import static com.openexchange.publish.online.infostore.FormStrings.FORM_LABEL_URL;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import java.util.Random;
import com.openexchange.datatypes.genericonf.DynamicFormDescription;
import com.openexchange.datatypes.genericonf.FormElement;
import com.openexchange.groupware.contexts.Context;
import com.openexchange.publish.Publication;
import com.openexchange.publish.PublicationException;
import com.openexchange.publish.PublicationTarget;
import com.openexchange.publish.helpers.AbstractPublicationService;
import com.openexchange.publish.helpers.SecurityStrategy;

/**
 * {@link InfostoreDocumentPublicationService}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 *
 */
public class InfostoreDocumentPublicationService extends AbstractPublicationService {

    private static final String SECRET = "secret";

    public static final String PREFIX = "/publications/documents";

    private static final String URL = "url";

    private Random random = new Random();

    private PublicationTarget buildTarget() {
        PublicationTarget target = new PublicationTarget();
        target.setDisplayName("Publish Infostore Document");
        target.setId("com.openexchange.publish.online.infostore.document");
        target.setModule("infostore/object");
        target.setPublicationService(this);

        DynamicFormDescription form = new DynamicFormDescription();
        form.add(FormElement.link("url", FORM_LABEL_URL, false, null));

        target.setFormDescription(form);

        return target;
    }

    private PublicationTarget target;

    @Override
    public PublicationTarget getTarget() throws PublicationException {
        if(target == null) {
            return target = buildTarget();
        }
        return target;
    }

    @Override
    public void beforeCreate(Publication publication) throws PublicationException {
        super.beforeCreate(publication);
        String secret = null;
        Context ctx = publication.getContext();
        while(true) {
            secret = generateSecret();
            if(getPublication(ctx, secret) == null) {
                break;
            }
        }
        publication.getConfiguration().put(SECRET, secret);
    }

    private String generateSecret() {
        long l1 = random.nextLong();
        long l2 = random.nextLong();
        return Long.toHexString(l1)+Long.toHexString(l2);
    }

    @Override
    public void modifyOutgoing(Publication publication) throws PublicationException {
        super.modifyOutgoing(publication);
        publication.getConfiguration().put(URL, PREFIX+"/"+publication.getContext().getContextId()+"/"+publication.getConfiguration().get(SECRET));
        publication.getConfiguration().remove(SECRET);
    }

    public Publication getPublication(Context ctx, String secret) throws PublicationException {
        Map<String, Object> query = new HashMap<String, Object>();
        query.put(SECRET, secret);
        Collection<Publication> result = STORAGE.search(ctx, getTarget().getId(), query);
        if(result == null || result.isEmpty()) {
            return null;
        }
        return result.iterator().next();
    }

    @Override
    protected SecurityStrategy getSecurityStrategy() {
        return ALLOW_ALL;
    }
}

==> open-xchange-publish-infostore-online_6.16.1.0.orig.tar.gz: open-xchange-publish-infostore-online-6.16.1.0/src/com/openexchange/publish/online/infostore/InfostoreDocumentPublicationService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.publish.online.infostore;

import static com.openexchange.publish.online.infostore.FormStrings.FORM_LABEL_URL;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import java.util.Random;
import com.openexchange.datatypes.genericonf.DynamicFormDescription;
import com.openexchange.datatypes.genericonf.FormElement;
import com.openexchange.groupware.contexts.Context;
import com.openexchange.publish.Publication;
import com.openexchange.publish.PublicationException;
import com.openexchange.publish.PublicationTarget;
import com.openexchange.publish.helpers.AbstractPublicationService;
import com.openexchange.publish.helpers.SecurityStrategy;

/**
 * {@link InfostoreDocumentPublicationService}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 *
 */
public class InfostoreDocumentPublicationService extends AbstractPublicationService {

    private static final String SECRET = "secret";

    public static final String PREFIX = "/publications/documents";

    private static final String URL = "url";

    private Random random = new Random();

    private PublicationTarget buildTarget() {
        PublicationTarget target = new PublicationTarget();
        target.setDisplayName("Publish Infostore Document");
        target.setId("com.openexchange.publish.online.infostore.document");
        target.setModule("infostore/object");
        target.setPublicationService(this);

        DynamicFormDescription form = new DynamicFormDescription();
        form.add(FormElement.link("url", FORM_LABEL_URL, false, null));

        target.setFormDescription(form);

        return target;
    }

    private PublicationTarget target;

    @Override
    public PublicationTarget getTarget() throws PublicationException {
        if(target == null) {
            return target = buildTarget();
        }
        return target;
    }

    @Override
    public void beforeCreate(Publication publication) throws PublicationException {
        super.beforeCreate(publication);
        String secret = null;
        Context ctx = publication.getContext();
        while(true) {
            secret = generateSecret();
            if(getPublication(ctx, secret) == null) {
                break;
            }
        }
        publication.getConfiguration().put(SECRET, secret);
    }

    private String generateSecret() {
        long l1 = random.nextLong();
        long l2 = random.nextLong();
        return Long.toHexString(l1)+Long.toHexString(l2);
    }

    @Override
    public void modifyOutgoing(Publication publication) throws PublicationException {
        super.modifyOutgoing(publication);
        publication.getConfiguration().put(URL, PREFIX+"/"+publication.getContext().getContextId()+"/"+publication.getConfiguration().get(SECRET));
        publication.getConfiguration().remove(SECRET);
    }

    public Publication getPublication(Context ctx, String secret) throws PublicationException {
        Map<String, Object> query = new HashMap<String, Object>();
        query.put(SECRET, secret);
        Collection<Publication> result = getDefaultStorage().search(ctx, getTarget().getId(), query);
        if(result == null || result.isEmpty()) {
            return null;
        }
        return result.iterator().next();
    }

    @Override
    protected SecurityStrategy getSecurityStrategy() {
        return ALLOW_ALL;
    }
}
